@@ -125,42 +125,34 @@
     class(out) = "adtest"
     return(out)
 }
-print.adtest = function(x, digits = 4, quote = TRUE, 
-    prefix = "", ...) {
+print.adtest = function(x, digits = 4, quote = TRUE, prefix = "", ...) {
     cat("\n")
     cat(strwrap(x$method, prefix = "\t"), sep = "\n")
     cat("\n")
     cat("data: ", x$data.name, "\n")
     out <- character()
     if (!is.null(x$statistic)) 
-        out <- c(out, paste(names(x$statistic), "=", format(round(x$statistic, 
-            4))))
+        out <- c(out, paste(names(x$statistic), "=", format(round(x$statistic, 4))))
     if (!is.null(x$parameter)) 
-        out <- c(out, paste(names(x$parameter), "=", format(round(x$parameter, 
-            3))))
+        out <- c(out, paste(names(x$parameter), "=", format(round(x$parameter, 3))))
     if (!is.null(x$p.value)) {
         fp <- format.pval(x$p.value, digits = digits)
         if (is.null(x$smaller)) 
-            out <- c(out, paste("p-value", if (substr(fp, 1L, 
-                1L) == "<") fp else paste("=", fp)))
+            out <- c(out, paste("p-value", if (substr(fp, 1L, 1L) == "<") fp else paste("=", fp)))
         if (x$tableValue) {
             if (x$smaller) 
-                out <- c(out, paste("p-value", if (substr(fp, 
-                  1L, 1L) == "<") fp else paste("<=", fp)))
-            else out <- c(out, paste("p-value", if (substr(fp, 
-                1L, 1L) == "=") fp else paste(">", fp)))
+                out <- c(out, paste("p-value", if (substr(fp, 1L, 1L) == "<") fp else paste("<=", fp)))
+            else out <- c(out, paste("p-value", if (substr(fp, 1L, 1L) == "=") fp else paste(">", fp)))
         }
         else {
-            out <- c(out, paste("p-value", if (substr(fp, 1L, 
-                1L) == "<") fp else paste("=", fp)))
+            out <- c(out, paste("p-value", if (substr(fp, 1L, 1L) == "<") fp else paste("=", fp)))
         }
     }
     cat(strwrap(paste(out, collapse = ", ")), sep = "\n")
     cat("alternative hypothesis: ")
     if (!is.null(x$null.value)) {
         if (length(x$null.value) == 1) {
-            cat("true", names(x$null.value), "is not equal to", 
-                x$null.value, "\n")
+            cat("true", names(x$null.value), "is not equal to", x$null.value, "\n")
         }
         else {
             cat(x$alternative, "\nnull values:\n")
@@ -168,8 +160,8 @@ print.adtest = function(x, digits = 4, quote = TRUE,
         }
     }
     if (!is.null(x$conf.int)) {
-        cat(format(100 * attr(x$conf.int, "conf.level")), "percent confidence interval:\n", 
-            format(c(x$conf.int[1L], x$conf.int[2L])), "\n")
+        cat(format(100 * attr(x$conf.int, "conf.level")), "percent confidence interval:\n", format(c(x$conf.int[1L], 
+            x$conf.int[2L])), "\n")
     }
     if (!is.null(x$estimate)) {
         cat("sample estimates:\n")
