@@ -1,6 +1,5 @@
-paretoChart = function(x, weight, showTable = TRUE, 
-    las = 0, main, col, border, xlab, ylab = "Frequency", percentVec, 
-    ...) {
+paretoChart = function(x, weight, showTable = TRUE, las = 0, main, col, border, xlab, ylab = "Frequency", 
+    percentVec, ...) {
     varName = deparse(substitute(x))
     corp.col = "pink3"
     corp.border = "red3"
@@ -24,8 +23,7 @@ paretoChart = function(x, weight, showTable = TRUE,
                 stop("names of weight and table do not match!")
             else {
                 for (i in 1:length(xtable)) {
-                  xtable[i] = weight[names(weight) == names(xtable)[i]] * 
-                    xtable[i]
+                  xtable[i] = weight[names(weight) == names(xtable)[i]] * xtable[i]
                 }
             }
         }
@@ -53,10 +51,9 @@ paretoChart = function(x, weight, showTable = TRUE,
         sumFreq = sum(xtable)
         percentage = xtable/sum(xtable) * 100
         cumPerc = cumFreq/sumFreq * 100
-        frameOut = data.frame(Frequency = as.numeric(xtable), 
-            Cum.Freq = cumFreq, Percentage = percentage, Cum.Perc = cumPerc)
-        names(frameOut) = c(ylab, paste("Cum.", ylab), "Percentage", 
-            "Cum. Percentage")
+        frameOut = data.frame(Frequency = as.numeric(xtable), Cum.Freq = cumFreq, Percentage = percentage, 
+            Cum.Perc = cumPerc)
+        names(frameOut) = c(ylab, paste("Cum.", ylab), "Percentage", "Cum. Percentage")
         row.names(frameOut) = names(xtable)
         frameInt = as.data.frame(t(frameOut))
         names(frameInt) = rep(" ", dim(frameInt)[2])
@@ -67,30 +64,22 @@ paretoChart = function(x, weight, showTable = TRUE,
         plot.new()
         if (las == 0 | las == 1) {
             mymai = par("mai")
-            mymai[1] = max(strheight(names(xtable), unit = "inches")) * 
-                3
-            mymai[4] = strheight("Cumulative Percentage", unit = "inches") * 
-                8
-            mymai[2] = max(strwidth(names(frameOut), unit = "inches")) * 
-                1.2
+            mymai[1] = max(strheight(names(xtable), unit = "inches")) * 3
+            mymai[4] = strheight("Cumulative Percentage", unit = "inches") * 8
+            mymai[2] = max(strwidth(names(frameOut), unit = "inches")) * 1.2
             par(mai = mymai, new = TRUE)
         }
         if (las == 2 | las == 3) {
             mymai = par("mai")
-            mymai[1] = max(strwidth(names(xtable), unit = "inches")) * 
-                1.4
-            mymai[4] = strheight("Cumulative Percentage", unit = "inches") * 
-                8
-            mymai[2] = max(strwidth(names(frameOut), unit = "inches")) * 
-                1.2
+            mymai[1] = max(strwidth(names(xtable), unit = "inches")) * 1.4
+            mymai[4] = strheight("Cumulative Percentage", unit = "inches") * 8
+            mymai[2] = max(strwidth(names(frameOut), unit = "inches")) * 1.2
             par(mai = mymai, new = TRUE)
         }
         if (showTable) {
             par(fig = c(0, 1, tablespace, 1))
-            xValue = barplot(xtable, axes = FALSE, las = las, 
-                width = 1, space = 0.2, xlim = c(0.2, 1.2 * length(xtable)), 
-                main = main, ylim = c(0, sum(xtable) + 0.01 * 
-                  (sum(xtable))), ylab = ylab, xlab = xlab, col = col, 
+            xValue = barplot(xtable, axes = FALSE, las = las, width = 1, space = 0.2, xlim = c(0.2, 1.2 * length(xtable)), 
+                main = main, ylim = c(0, sum(xtable) + 0.01 * (sum(xtable))), ylab = ylab, xlab = xlab, col = col, 
                 border = border)
             axis(1, at = xValue, labels = names(xtable), las = las)
             axis(2)
@@ -102,28 +91,23 @@ paretoChart = function(x, weight, showTable = TRUE,
             mymai[1] = 0
             mymai[3] = 0
             par(mai = mymai)
-            plot(xValue, rep(1, length(xValue)), xlim = c(0.2, 
-                1.2 * length(xtable)), ylim = c(0, 5), axes = FALSE, 
+            plot(xValue, rep(1, length(xValue)), xlim = c(0.2, 1.2 * length(xtable)), ylim = c(0, 5), axes = FALSE, 
                 ylab = "", type = "n")
-            axis(2, pos = 0.2, at = 1:4, labels = rev(c(ylab, 
-                paste("Cum.", ylab), "Percentage", "Cum. Percentage")), 
+            axis(2, pos = 0.2, at = 1:4, labels = rev(c(ylab, paste("Cum.", ylab), "Percentage", "Cum. Percentage")), 
                 tick = FALSE, las = 1)
             numCol = dim(frameInt)[2]
             numRow = dim(frameInt)[1]
             for (i in 1:numCol) {
                 for (j in 1:numRow) {
-                  text(xValue[i], numRow + 1 - j, round(frameInt[j, 
-                    i]), adj = c(1, 0.5))
+                  text(xValue[i], numRow + 1 - j, round(frameInt[j, i]), adj = c(1, 0.5))
                 }
             }
         }
         else {
             mymai[2] = mymai[4]
             par(mai = mymai)
-            xValue = barplot(xtable, axes = FALSE, las = las, 
-                width = 1, space = 0.2, xlim = c(0.2, 1.2 * length(xtable)), 
-                main = main, ylim = c(0, sum(xtable) + 0.01 * 
-                  (sum(xtable))), ylab = ylab, xlab = xlab, col = col, 
+            xValue = barplot(xtable, axes = FALSE, las = las, width = 1, space = 0.2, xlim = c(0.2, 1.2 * length(xtable)), 
+                main = main, ylim = c(0, sum(xtable) + 0.01 * (sum(xtable))), ylab = ylab, xlab = xlab, col = col, 
                 border = border)
             axis(1, at = xValue, labels = names(xtable), las = las)
             axis(2)
