@@ -1,11 +1,9 @@
 .c4 = function(n) {
     if (n > 1 && n < 342) 
-        sqrt(2/(n - 1)) * (factorial(n/2 - 1)/factorial((n - 
-            1)/2 - 1))
+        sqrt(2/(n - 1)) * (factorial(n/2 - 1)/factorial((n - 1)/2 - 1))
     else stop("n needs to be bigger than 1 and smaller than 342")
 }
-.sdSg = function(x, grouping = NULL, method = c("NOWEIGHT", 
-    "MVLUE", "RMSDF"), na.rm = TRUE, DB = TRUE) {
+.sdSg = function(x, grouping = NULL, method = c("NOWEIGHT", "MVLUE", "RMSDF"), na.rm = TRUE, DB = TRUE) {
     if (!is.data.frame(x) && !is.vector(x) && is.numeric(x)) 
         stop("x needs to be either a data.frame or a vector and numeric")
     if (is.null(grouping)) 
@@ -34,22 +32,18 @@
 .boxCoxTrans = function(x, lambda) {
     if (abs(lambda) <= 1e-06) 
         y = log(x, base = exp(1))
-    else y = (x^lambda - 1)/(lambda * ((prod(x, na.rm = TRUE)^(1/length(na.omit(x))))^(lambda - 
-        1)))
+    else y = (x^lambda - 1)/(lambda * ((prod(x, na.rm = TRUE)^(1/length(na.omit(x))))^(lambda - 1)))
     return(y)
 }
 .bctSD = function(lambda, x) {
     if (abs(lambda) <= 1e-06) 
         y = log(x, base = exp(1))
-    else y = (x^lambda - 1)/(lambda * ((prod(x, na.rm = TRUE)^(1/length(na.omit(x))))^(lambda - 
-        1)))
+    else y = (x^lambda - 1)/(lambda * ((prod(x, na.rm = TRUE)^(1/length(na.omit(x))))^(lambda - 1)))
     return(sd(y))
 }
-pcr = function(x, distribution = "normal", lsl, usl, 
-    target, boxcox = FALSE, lambda, main, xlim, ylim, grouping = NULL, 
-    std.dev = NULL, conf.level = 0.9973002, start, lineWidth = 2, 
-    lineCol = "red", lineType = "solid", specCol = "black", specWidth = 2, 
-    cex.text = 2, cex.val = 1.5, cex.col = "darkgray", ...) {
+pcr = function(x, distribution = "normal", lsl, usl, target, boxcox = FALSE, lambda, main, xlim, 
+    ylim, grouping = NULL, std.dev = NULL, conf.level = 0.9973002, start, lineWidth = 2, lineCol = "red", lineType = "solid", 
+    specCol = "black", specWidth = 2, cex.text = 2, cex.val = 1.5, cex.col = "darkgray", ...) {
     DB = FALSE
     require(MASS, quietly = TRUE)
     par.orig <- par(c("mar", "oma", "mfrow"))
@@ -91,12 +85,10 @@ pcr = function(x, distribution = "normal", lsl, usl,
     center = mean(x)
     if (!is.null(x) & !is.null(grouping)) {
         if (nrow(x) != nrow(grouping)) 
-            stop(paste("length of ", deparse(substitute(grouping)), 
-                " differs from length of ", varName))
+            stop(paste("length of ", deparse(substitute(grouping)), " differs from length of ", varName))
     }
     if (missing(main)) 
-        main = paste("Process Capability using", as.character(distribution), 
-            "distribution for\n", varName)
+        main = paste("Process Capability using", as.character(distribution), "distribution for\n", varName)
     if (is.null(std.dev)) {
         if (is.null(grouping)) 
             std.dev = .sdSg(x)
@@ -110,9 +102,8 @@ pcr = function(x, distribution = "normal", lsl, usl,
         print(paste("confHigh:", confHigh))
         print(paste("confLow:", confLow))
     }
-    distWhichNeedParameters = c("weibull", "logistic", "gamma", 
-        "exponential", "f", "geometric", "chi-squared", "negative binomial", 
-        "poisson")
+    distWhichNeedParameters = c("weibull", "logistic", "gamma", "exponential", "f", "geometric", "chi-squared", 
+        "negative binomial", "poisson")
     if (is.character(distribution)) {
         qFun = .charToDistFunc(distribution, type = "q")
         pFun = .charToDistFunc(distribution, type = "p")
@@ -196,10 +187,8 @@ pcr = function(x, distribution = "normal", lsl, usl,
     }
     par(mar = c(0, 0, 0, 0) + 0.1)
     par(oma = c(12, 4, 4, 5) + 0.1)
-    layout(matrix(c(1, 1, 1, 2, 1, 1, 1, 3, 1, 1, 1, 4), nr = 3, 
-        byrow = TRUE))
-    do.call(hist, c(list(x[, 1], freq = FALSE, xlim = xlim, ylim = ylim, 
-        main = ""), parList))
+    layout(matrix(c(1, 1, 1, 2, 1, 1, 1, 3, 1, 1, 1, 4), nr = 3, byrow = TRUE))
+    do.call(hist, c(list(x[, 1], freq = FALSE, xlim = xlim, ylim = ylim, main = ""), parList))
     abline(h = 0, col = "gray")
     tempList = parList
     tempList$col = 1
@@ -209,41 +198,25 @@ pcr = function(x, distribution = "normal", lsl, usl,
     abline(v = usl, col = specCol, lwd = specWidth)
     abline(v = lsl, col = specCol, lwd = specWidth)
     abline(v = target, col = specCol, lwd = specWidth)
-    text(lsl, 0.9 * max(ylim), "LSL", pos = 2, col = cex.col, 
-        cex = cex.text)
-    text(usl, 0.9 * max(ylim), "USL", pos = 4, col = cex.col, 
-        cex = cex.text)
-    text(target, max(ylim), "TARGET", pos = 1, col = cex.col, 
-        cex = cex.text)
+    text(lsl, 0.9 * max(ylim), "LSL", pos = 2, col = cex.col, cex = cex.text)
+    text(usl, 0.9 * max(ylim), "USL", pos = 4, col = cex.col, cex = cex.text)
+    text(target, max(ylim), "TARGET", pos = 1, col = cex.col, cex = cex.text)
     title(main = main, outer = TRUE)
     pos1 = 0.025
     pos2 = 0.6
-    mtext(expression(bar(x)), at = pos1, side = 1, line = 5, 
-        cex = 1.5, adj = 1, outer = TRUE)
-    mtext(paste(" =", round(center, 3)), at = pos1, side = 1, 
-        line = 5, cex = 1.5, adj = 0, outer = TRUE)
-    mtext("s", at = pos1, side = 1, line = 7, cex = 1.5, adj = 1, 
-        outer = TRUE)
-    mtext(paste(" =", round(std.dev, 3)), at = pos1, side = 1, 
-        line = 7, cex = 1.5, adj = 0, outer = TRUE)
-    mtext("n", at = pos1, side = 1, line = 9, cex = 1.5, adj = 1, 
-        outer = TRUE)
-    mtext(paste(" =", numObs), at = pos1, side = 1, line = 9, 
-        cex = 1.5, adj = 0, outer = TRUE)
-    mtext("Nominal Value", at = pos2, side = 1, line = 5, cex = 1.5, 
-        adj = 1, outer = TRUE)
-    mtext(paste(" =", round(target, 3)), at = pos2, side = 1, 
-        line = 5, cex = 1.5, adj = 0, outer = TRUE)
-    mtext("USL", at = pos2, side = 1, line = 7, cex = 1.5, adj = 1, 
-        outer = TRUE)
-    mtext(paste(" =", round(usl, 3)), at = pos2, side = 1, line = 7, 
-        cex = 1.5, adj = 0, outer = TRUE)
-    mtext("LSL", at = pos2, side = 1, line = 9, cex = 1.5, adj = 1, 
-        outer = TRUE)
-    mtext(paste(" =", round(lsl, 3)), at = pos2, side = 1, line = 9, 
-        cex = 1.5, adj = 0, outer = TRUE)
-    plot(0:5, 0:5, type = "n", axes = FALSE, xlab = "", ylab = "", 
-        main = "")
+    mtext(expression(bar(x)), at = pos1, side = 1, line = 5, cex = 1.5, adj = 1, outer = TRUE)
+    mtext(paste(" =", round(center, 3)), at = pos1, side = 1, line = 5, cex = 1.5, adj = 0, outer = TRUE)
+    mtext("s", at = pos1, side = 1, line = 7, cex = 1.5, adj = 1, outer = TRUE)
+    mtext(paste(" =", round(std.dev, 3)), at = pos1, side = 1, line = 7, cex = 1.5, adj = 0, outer = TRUE)
+    mtext("n", at = pos1, side = 1, line = 9, cex = 1.5, adj = 1, outer = TRUE)
+    mtext(paste(" =", numObs), at = pos1, side = 1, line = 9, cex = 1.5, adj = 0, outer = TRUE)
+    mtext("Nominal Value", at = pos2, side = 1, line = 5, cex = 1.5, adj = 1, outer = TRUE)
+    mtext(paste(" =", round(target, 3)), at = pos2, side = 1, line = 5, cex = 1.5, adj = 0, outer = TRUE)
+    mtext("USL", at = pos2, side = 1, line = 7, cex = 1.5, adj = 1, outer = TRUE)
+    mtext(paste(" =", round(usl, 3)), at = pos2, side = 1, line = 7, cex = 1.5, adj = 0, outer = TRUE)
+    mtext("LSL", at = pos2, side = 1, line = 9, cex = 1.5, adj = 1, outer = TRUE)
+    mtext(paste(" =", round(lsl, 3)), at = pos2, side = 1, line = 9, cex = 1.5, adj = 0, outer = TRUE)
+    plot(0:5, 0:5, type = "n", axes = FALSE, xlab = "", ylab = "", main = "")
     box()
     text(2, 1, expression(c[p]), pos = 2, cex = cex.val)
     text(2, 1, paste("=", round(cp, 2)), pos = 4, cex = cex.val)
@@ -254,8 +227,7 @@ pcr = function(x, distribution = "normal", lsl, usl,
     text(2, 4, expression(c[pkU]), pos = 2, cex = cex.val)
     text(2, 4, paste("=", round(cpu, 2)), pos = 4, cex = cex.val)
     index = 0:(length(estimates) + 3)
-    plot(0:5, c(0:4, max(index)), type = "n", axes = FALSE, xlab = "", 
-        ylab = "", main = "")
+    plot(0:5, c(0:4, max(index)), type = "n", axes = FALSE, xlab = "", ylab = "", main = "")
     box()
     adTestStats = .myADTest(x[, 1], distribution)
     print(adTestStats)
@@ -270,17 +242,13 @@ pcr = function(x, distribution = "normal", lsl, usl,
         p = NA
     }
     text(2, rev(index)[2], "A", pos = 2, cex = cex.val)
-    text(2, rev(index)[2], paste("=", round(A, 3)), pos = 4, 
-        cex = cex.val)
+    text(2, rev(index)[2], paste("=", round(A, 3)), pos = 4, cex = cex.val)
     text(2, rev(index)[3], "p", pos = 2, cex = cex.val)
-    text(2, rev(index)[3], paste("=", round(p, 3)), pos = 4, 
-        cex = cex.val)
+    text(2, rev(index)[3], paste("=", round(p, 3)), pos = 4, cex = cex.val)
     j = 1
     for (i in 3:(3 + length(estimates) - 1)) {
-        try(text(2, rev(index)[i + 1], names(estimates)[[j]], 
-            pos = 2, cex = cex.val), silent = TRUE)
-        try(text(2, rev(index)[i + 1], paste("=", round(estimates[[j]], 
-            3)), pos = 4, cex = cex.val), silent = TRUE)
+        try(text(2, rev(index)[i + 1], names(estimates)[[j]], pos = 2, cex = cex.val), silent = TRUE)
+        try(text(2, rev(index)[i + 1], paste("=", round(estimates[[j]], 3)), pos = 4, cex = cex.val), silent = TRUE)
         j = j + 1
     }
     qqPlot(x[, 1], y = distribution, ylab = "", main = "", axes = F)
