@@ -1,5 +1,6 @@
-contourPlot3 = function(x, y, z, response, data = NULL, xlim, ylim, zlim, main, xlab, ylab, zlab, border, sub, 
-    form = "linear", phi, theta, ticktype, col = 1, col.text, cex.axis, axes = TRUE, steps, factors, fun, plot) {
+contourPlot3 = function(x, y, z, response, data = NULL, xlim, ylim, zlim, main, xlab, ylab, zlab, 
+    border, sub, form = "linear", phi, theta, ticktype, col = 1, col.text, cex.axis, axes = TRUE, steps, factors, 
+    fun, plot) {
     DB = FALSE
     out = list()
     mdo = data
@@ -38,7 +39,8 @@ contourPlot3 = function(x, y, z, response, data = NULL, xlim, ylim, zlim, main,
     col.axis = par("col.axis")
     if (!is.function(col)) {
         if (identical(col, 1)) 
-            col = colorRampPalette(c("#00007F", "blue", "#007FFF", "cyan", "#7FFF7F", "yellow", "#FF7F00", "red", "#7F0000"))
+            col = colorRampPalette(c("#00007F", "blue", "#007FFF", "cyan", "#7FFF7F", "yellow", "#FF7F00", 
+                "red", "#7F0000"))
         if (identical(col, 2)) 
             col = colorRampPalette(c("blue", "white", "red"), space = "Lab")
         if (identical(col, 3)) 
@@ -131,8 +133,9 @@ contourPlot3 = function(x, y, z, response, data = NULL, xlim, ylim, zlim, main,
     mtext(zlab, 1, at = 1.025, cex = 1.5)
     invisible(mat)
 }
-wirePlot3 = function(x, y, z, response, data = NULL, xlim, ylim, zlim, main, xlab, ylab, zlab, border, sub, 
-    form = "linear", phi, theta, ticktype, col = 1, col.text, cex.axis, axes = TRUE, steps, factors, fun, plot) {
+wirePlot3 = function(x, y, z, response, data = NULL, xlim, ylim, zlim, main, xlab, ylab, zlab, border, 
+    sub, form = "linear", phi, theta, ticktype, col = 1, col.text, cex.axis, axes = TRUE, steps, factors, fun, 
+    plot) {
     DB = FALSE
     out = list()
     mdo = data
@@ -170,7 +173,8 @@ wirePlot3 = function(x, y, z, response, data = NULL, xlim, ylim, zlim, main, xla
         steps = 100
     if (!is.function(col)) {
         if (identical(col, 1)) 
-            col = colorRampPalette(c("#00007F", "blue", "#007FFF", "cyan", "#7FFF7F", "yellow", "#FF7F00", "red", "#7F0000"))
+            col = colorRampPalette(c("#00007F", "blue", "#007FFF", "cyan", "#7FFF7F", "yellow", "#FF7F00", 
+                "red", "#7F0000"))
         if (identical(col, 2)) 
             col = colorRampPalette(c("blue", "white", "red"), space = "Lab")
         if (identical(col, 3)) 
@@ -246,13 +250,16 @@ wirePlot3 = function(x, y, z, response, data = NULL, xlim, ylim, zlim, main, xla
     }
     maxim = max(mat, na.rm = TRUE) * acc
     minim = min(mat, na.rm = TRUE) * acc
-    per = persp(x = seq(0, acc, length = acc), y = seq(0, acc * sca, length = ncmat), mat * acc, phi = .phi, theta = .theta, 
-        scale = TRUE, col = "transparent", border = FALSE, box = FALSE, main = main, xlab = xlab, ylab = ylab)
+    per = persp(x = seq(0, acc, length = acc), y = seq(0, acc * sca, length = ncmat), mat * acc, phi = .phi, 
+        theta = .theta, scale = TRUE, col = "transparent", border = FALSE, box = FALSE, main = main, xlab = xlab, 
+        ylab = ylab)
     lineList = contourLines(x = seq(0, acc, length = acc), y = seq(0, acc * sca, length = ncmat), mat)
     for (i in seq(along = lineList)) lines(trans3d(lineList[[i]]$x, lineList[[i]]$y, z = minim, pmat = per))
     if (.phi < 90) {
-        lines(trans3d(x = seq(0, acc/2, length = 10), y = seq(0, acc * sca, length = 10), z = maxim, pmat = per), lty = 2)
-        lines(trans3d(x = seq(acc, acc/2, length = 10), y = seq(0, acc * sca, length = 10), z = maxim, pmat = per), lty = 2)
+        lines(trans3d(x = seq(0, acc/2, length = 10), y = seq(0, acc * sca, length = 10), z = maxim, pmat = per), 
+            lty = 2)
+        lines(trans3d(x = seq(acc, acc/2, length = 10), y = seq(0, acc * sca, length = 10), z = maxim, pmat = per), 
+            lty = 2)
         lines(trans3d(x = 0:acc, y = 0, z = maxim, pmat = per), lty = 2)
     }
     if (.theta > 323 || .theta < 37) {
@@ -265,10 +272,10 @@ wirePlot3 = function(x, y, z, response, data = NULL, xlim, ylim, zlim, main, xla
     if (.theta > 156 && .theta < 323) {
         lines(trans3d(x = acc, y = 0, z = minim:maxim, pmat = per), lty = 2)
     }
-    lines(trans3d(x = seq(0, acc/2, length = 10), y = seq(0, acc * sca, length = 10), z = minim, pmat = per), lty = 1, 
-        lwd = 2)
-    lines(trans3d(x = seq(acc, acc/2, length = 10), y = seq(0, acc * sca, length = 10), z = minim, pmat = per), lty = 1, 
-        lwd = 2)
+    lines(trans3d(x = seq(0, acc/2, length = 10), y = seq(0, acc * sca, length = 10), z = minim, pmat = per), 
+        lty = 1, lwd = 2)
+    lines(trans3d(x = seq(acc, acc/2, length = 10), y = seq(0, acc * sca, length = 10), z = minim, pmat = per), 
+        lty = 1, lwd = 2)
     lines(trans3d(x = 0:acc, y = 0, z = minim, pmat = per), lty = 1, lwd = 2)
     text(trans3d(x = acc/2 + acc/50, y = acc * sca + acc * sca/50, z = minim, pmat = per), labels = xlab, lwd = 2)
     text(trans3d(x = -acc/50, y = -acc * sca/50, z = minim, pmat = per), labels = ylab, lwd = 2)
@@ -277,8 +284,10 @@ wirePlot3 = function(x, y, z, response, data = NULL, xlim, ylim, zlim, main, xla
     persp(x = seq(0, acc, length = acc), y = seq(0, acc * sca, length = ncmat), mat * acc, phi = .phi, theta = .theta, 
         scale = TRUE, col = color[facetcol], border = FALSE, box = FALSE)
     if (.phi > 0) {
-        lines(trans3d(x = seq(0, acc/2, length = 10), y = seq(0, acc * sca, length = 10), z = maxim, pmat = per), lty = 2)
-        lines(trans3d(x = seq(acc, acc/2, length = 10), y = seq(0, acc * sca, length = 10), z = maxim, pmat = per), lty = 2)
+        lines(trans3d(x = seq(0, acc/2, length = 10), y = seq(0, acc * sca, length = 10), z = maxim, pmat = per), 
+            lty = 2)
+        lines(trans3d(x = seq(acc, acc/2, length = 10), y = seq(0, acc * sca, length = 10), z = maxim, pmat = per), 
+            lty = 2)
         lines(trans3d(x = 0:acc, y = 0, z = maxim, pmat = per), lty = 2)
     }
     if (.theta > 37 && .theta < 156) {
